%% Master Thesis - Non-linear Wave Impact on Monopile Structures

%  Philipp Schpfer - KTH (Stockholm) & NTNU (Trondheim)

%  In Corporation With Ramboll Denmark AS, Esbjerg

%  21.06.2016 -  Results of ULS assessment of monopile foundation
%  OCW3D plus ROSA - breaking filter BF = 0.4g
 
clear all
close all
clc

%% Reading data
% First number (1-3) = seed number
% Second number 1-3) = x-position along the wave 
% x1 = 200.0m; x2 = 650.0m; x3 = 1100.0m
% W = wave profile [m]; O = overturning moment [kNm]; F = shear force [kN]

data = xlsread('Results.xls');

t = data(:,1);              % [s] time

%% Quasi-static analysis (QS)

% Seed 1, x1
W_QS_1_1 = data(:,2);           
O_QS_1_1 = data(:,3);           
F_QS_1_1 = data(:,4);    

% Seed 1, x2
W_QS_1_2 = data(:,5);           
O_QS_1_2 = data(:,6);           
F_QS_1_2 = data(:,7); 

% Seed 1, x3
W_QS_1_3 = data(:,8);           
O_QS_1_3 = data(:,9);           
F_QS_1_3 = data(:,10);

% Seed 2, x1
W_QS_2_1 = data(:,11);           
O_QS_2_1 = data(:,12);           
F_QS_2_1 = data(:,13);

% Seed 2, x2
W_QS_2_2 = data(:,14);           
O_QS_2_2 = data(:,15);           
F_QS_2_2 = data(:,16); 

% Seed 2, x3
W_QS_2_3 = data(:,17);           
O_QS_2_3 = data(:,18);           
F_QS_2_3 = data(:,19);

% Seed 3, x1
W_QS_3_1 = data(:,20);           
O_QS_3_1 = data(:,21);           
F_QS_3_1 = data(:,22);

% Seed 3, x2
W_QS_3_2 = data(:,23);           
O_QS_3_2 = data(:,24);           
F_QS_3_2 = data(:,25);

% Seed 3, x3
W_QS_3_3 = data(:,26);           
O_QS_3_3 = data(:,27);           
F_QS_3_3 = data(:,28);

% Seed 4, x1
W_QS_4_1 = data(:,29);           
O_QS_4_1 = data(:,30);           
F_QS_4_1 = data(:,31);

% Seed 4, x2
W_QS_4_2 = data(:,32);           
O_QS_4_2 = data(:,33);           
F_QS_4_2 = data(:,34); 

% Seed 4, x3
W_QS_4_3 = data(:,35);           
O_QS_4_3 = data(:,36);           
F_QS_4_3 = data(:,37);

% Seed 5, x1
W_QS_5_1 = data(:,38);           
O_QS_5_1 = data(:,39);           
F_QS_5_1 = data(:,40);

% Seed 5, x2
W_QS_5_2 = data(:,41);           
O_QS_5_2 = data(:,42);           
F_QS_5_2 = data(:,43);

% Seed 5, x3
W_QS_5_3 = data(:,44);           
O_QS_5_3 = data(:,45);           
F_QS_5_3 = data(:,46);

%%
figure(1)
plot(t,W_QS_3_3,'-b');
axis([0 3600 -15 15]);
grid on
xlabel('Time, t [s]');
ylabel('Wave profile, \eta [m]');
legend('x_1 = 200.0 m');

%% Wave plotting
figure(1)
plot(t,W_QS_1_1,'-b','LineWidth',2);
axis([1100 1300 -10 10]);
grid on
xlabel('Time, t [s]');
ylabel('Wave profile, \eta [m]');
legend('x_1 = 200.0 m');

figure(2)
plot(t,W_QS_1_2,'-r','LineWidth',2);
axis([1100 1300 -10 10]);
grid on
xlabel('Time, t [s]');
ylabel('Wave profile, \eta [m]');
legend('x_2 = 650.0 m');

figure(3)
plot(t,W_QS_1_3,'-g','LineWidth',2);
axis([1100 1300 -10 10]);
grid on
xlabel('Time, t [s]');
ylabel('Wave profile, \eta [m]');
legend('x_3 = 1100.0 m');


%%
% Seed 1, different x-position
figure(1)
plot(t,W_QS_1_1,'-b',t,W_QS_1_2,'-r',t,W_QS_1_3,'-g','LineWidth',2);
axis([0 3600 -15 15]);
grid on
xlabel('Time, t [s]');
ylabel('Wave profile, \eta [m]');
legend('x_1 = 200.0 m','x_2 = 650.0 m','x_3 = 1100.0 m');

% Seed 2, different x-position
figure(2)
plot(t,W_QS_2_1,'-b',t,W_QS_2_2,'-r',t,W_QS_2_3,'-g');
axis([0 3600 -15 15]);
grid on
xlabel('Time, t [s]');
ylabel('Wave profile, \eta [m]');
legend('x_1 = 200.0 m','x_2 = 650.0 m','x_3 = 1100.0 m');

% Seed 3, different x-position
figure(3)
plot(t,W_QS_3_1,'-b',t,W_QS_3_2,'-r',t,W_QS_3_3,'-g');
axis([0 3600 -15 15]);
grid on
xlabel('Time, t [s]');
ylabel('Wave profile, \eta [m]');
legend('x_1 = 200.0 m','x_2 = 650.0 m','x_3 = 1100.0 m');

% Seed 4, different x-position
figure(4)
plot(t,W_QS_4_1,'-b',t,W_QS_4_2,'-r',t,W_QS_4_3,'-g');
axis([0 3600 -15 15]);
grid on
xlabel('Time, t [s]');
ylabel('Wave profile, \eta [m]');
legend('x_1 = 200.0 m','x_2 = 650.0 m','x_3 = 1100.0 m');

% Seed 5, different x-position
figure(5)
plot(t,W_QS_5_1,'-b',t,W_QS_5_2,'-r',t,W_QS_5_3,'-g');
axis([0 3600 -15 15]);
grid on
xlabel('Time, t [s]');
ylabel('Wave profile, \eta [m]');
legend('x_1 = 200.0 m','x_2 = 650.0 m','x_3 = 1100.0 m');

% x1, different seed
figure(6)
plot(t,W_QS_1_1,'-b',t,W_QS_2_1,'-r',t,W_QS_3_1,'-g',...
    t,W_QS_4_1,'-c',t,W_QS_5_1,'-k','LineWidth',2);
axis([0 3600 -15 15]);
grid on
xlabel('Time, t [s]');
ylabel('Wave profile, \eta [m]');
legend('Seed 1','Seed 2','Seed 3','Seed 4','Seed 5');

% x2, different seed
figure(7)
plot(t,W_QS_1_2,'-b',t,W_QS_2_2,'-r',t,W_QS_3_2,'-g',...
    t,W_QS_4_2,'-c',t,W_QS_5_2,'-k');
axis([0 3600 -15 15]);
grid on
xlabel('Time, t [s]');
ylabel('Wave profile, \eta [m]');
legend('Seed 1','Seed 2','Seed 3','Seed 4','Seed 5');

% x3, different seed
figure(8)
plot(t,W_QS_1_3,'-b',t,W_QS_2_3,'-r',t,W_QS_3_3,'-g',...
    t,W_QS_4_3,'-c',t,W_QS_5_3,'-k');
axis([0 3600 -15 15]);
grid on
xlabel('Time, t [s]');
ylabel('Wave profile, \eta [m]');
legend('Seed 1','Seed 2','Seed 3','Seed 4','Seed 5');

%% Quasi-static: OTM vs. wave (example plot)

figure(9)
[AX,H1,H2] = plotyy(t,O_QS_5_3,t,W_QS_5_3);
grid on
hold on; 
set(H1,'Color','r');
set(H2,'Color','b');
set(H1,'LineWidth',2);
set(H2,'LineWidth',2);
legend('Overturning moment (seed 1, x_1)','Wave profile','Location','SouthEast');

set(AX(1),'XLim', [0 3600]);
set(AX(2),'XLim', [0 3600]);
set(AX(1),'YLim', [-3e5 3e5]);
set(AX(2),'YLim', [-15 15]);
set(AX(1),'YColor','k');
set(AX(2),'YColor','k');

set(get(AX(1),'Ylabel'),'string','Overturning moment (quasi-static), OTM [kNm]','Color','r');
set(get(AX(2),'Ylabel'),'string','Surface elevation, \eta [m]','Color','b');
xlabel('Time, s [m]');

%% Power density spectrum
% Seed 1, different x-positions

data2 = xlsread('S1X4.xls');

W_QS_1_4 = data2(:,2);              

smoothV = 2^6;
Hs=spectrum.periodogram; 
fs1 = 1/(t(2)-t(1));
amp1 = psd(Hs,W_QS_1_1,'Fs',fs1);
freq1 = (amp1.Frequencies);

fs2 = 1/(t(2)-t(1));
amp2 = psd(Hs,W_QS_1_2,'Fs',fs2);
freq2 = (amp2.Frequencies);
 
fs3 = 1/(t(2)-t(1));  
amp3 = psd(Hs,W_QS_1_3,'Fs',fs3);
freq3 = (amp3.Frequencies);

figure(10)
plot(freq1,(conv(mag2db(amp1.data),ones(smoothV,1),'same')/smoothV),'-b','LineWidth',2)
hold on
plot(freq2,(conv(mag2db(amp2.data),ones(smoothV,1),'same')/smoothV),'-r','LineWidth',2)
hold on
plot(freq3,(conv(mag2db(amp3.data),ones(smoothV,1),'same')/smoothV),'-g','LineWidth',2)
% hold on
% plot(freq4,(conv(mag2db(amp4.data),ones(smoothV,1),'same')/smoothV),'-c','LineWidth',2)
xlabel('Frequency, f [Hz]');
ylabel('Power spectral density, PSD [dB/Hz]');
% legend('x_1 = 200.0 m','x_2 = 650.0 m','x_3 = 1100.0 m','x_3 = 1100.0 m')
axis([0 0.3 -30 50]),
grid on

% x1, different seeds

smoothV = 2^7;
Hs=spectrum.periodogram; 
fs4 = 1/(t(2)-t(1));
amp4 = psd(Hs,O_QS_1_1,'Fs',fs4);
freq4 = (amp1.Frequencies);

fs5 = 1/(t(2)-t(1));
amp5 = psd(Hs,O_QS_2_1,'Fs',fs5);
freq5 = (amp5.Frequencies);

fs6 = 1/(t(2)-t(1));
amp6 = psd(Hs,O_QS_3_1,'Fs',fs6);
freq6 = (amp6.Frequencies);

fs7 = 1/(t(2)-t(1));
amp7 = psd(Hs,O_QS_4_1,'Fs',fs7);
freq7 = (amp7.Frequencies);

fs8 = 1/(t(2)-t(1));
amp8 = psd(Hs,O_QS_5_1,'Fs',fs8);
freq8 = (amp8.Frequencies);

figure(11)
plot(freq4,(conv(mag2db(amp4.data),ones(smoothV,1),'same')/smoothV),'-b')
hold on
plot(freq5,(conv(mag2db(amp5.data),ones(smoothV,1),'same')/smoothV),'-r')
hold on
plot(freq6,(conv(mag2db(amp6.data),ones(smoothV,1),'same')/smoothV),'-g')
hold on
plot(freq7,(conv(mag2db(amp7.data),ones(smoothV,1),'same')/smoothV),'-c')
hold on
plot(freq8,(conv(mag2db(amp8.data),ones(smoothV,1),'same')/smoothV),'-k')
xlabel('Frequency, f [1/s]');
ylabel('Power spectral density, PSD [dB/Hz]');
legend('Seed 1','Seed 2','Seed 3','Seed 4','Seed 5')
axis([0 0.5 120 200]),
grid on
