%% Master Thesis - Non-linear Wave Impact on Monopile Structures

%  Philipp Schpfer - KTH (Stockholm) & NTNU (Trondheim)

%  In Corporation With Ramboll Denmark AS, Esbjerg

%  21.06.2016 -  Plotting results of single wave assessment & final evaluation of comparison study
%  OCW3D plus ROSA - breaking filter BF = 0.4g
%  QUASI-STATIC 

clear all
close all
clc

%% Loading data

load('QS_S1_X1_04.mat')
load('QS_S1_X2_04.mat')
load('QS_S1_X3_04.mat')

load('QS_S2_X1_04.mat')
load('QS_S2_X2_04.mat')
load('QS_S2_X3_04.mat')

load('QS_S3_X1_04.mat')
load('QS_S3_X2_04.mat')
load('QS_S3_X3_04.mat')

load('QS_S4_X1_04.mat')
load('QS_S4_X2_04.mat')
load('QS_S4_X3_04.mat')

load('QS_S5_X1_04.mat')
load('QS_S5_X2_04.mat')
load('QS_S5_X3_04.mat')

%% PLotting: wave height vs. OTM

figure(1)
plot(QS_S1_X1_04(:,1),QS_S1_X1_04(:,3),'.b',QS_S1_X2_04(:,1),QS_S1_X2_04(:,3),'xb',...
    QS_S1_X3_04(:,1),QS_S1_X3_04(:,3),'sb')
hold on
plot(QS_S2_X1_04(:,1),QS_S2_X1_04(:,3),'+r',QS_S2_X2_04(:,1),QS_S2_X2_04(:,3),'dr',...
    QS_S2_X3_04(:,1),QS_S2_X3_04(:,3),'<r')
hold on
plot(QS_S3_X1_04(:,1),QS_S3_X1_04(:,3),'om',QS_S3_X2_04(:,1),QS_S3_X2_04(:,3),'*m',...
    QS_S3_X3_04(:,1),QS_S3_X3_04(:,3),'>m')
hold on
plot(QS_S4_X1_04(:,1),QS_S4_X1_04(:,3),'pc',QS_S4_X2_04(:,1),QS_S4_X2_04(:,3),'vc',...
    QS_S4_X3_04(:,1),QS_S4_X3_04(:,3),'*c')
hold on
plot(QS_S5_X1_04(:,1),QS_S5_X1_04(:,3),'^g',QS_S5_X2_04(:,1),QS_S5_X2_04(:,3),'hg',...
    QS_S5_X3_04(:,1),QS_S5_X3_04(:,3),'>g')

grid on
axis([0 20 0 2e5]);
xlabel('Wave height, H [m]');
ylabel('Overturning moment (quasi-static),OTM [kNm]');  
legend('Seed 1; x_1','Seed 1; x_2','Seed 1; x_3',...
    'Seed 2; x_1','Seed 2; x_2','Seed 2; x_3',...
    'Seed 3; x_1','Seed 3; x_2','Seed 3; x_3',...
    'Seed 4; x_1','Seed 4; x_2','Seed 4; x_3',...
    'Seed 5; x_1','Seed 5; x_2','Seed 5; x_3','Location','SouthEast');

%% PLotting: wave period vs. OTM

figure(2)
plot(QS_S1_X1_04(:,2),QS_S1_X1_04(:,3),'.b',QS_S1_X2_04(:,2),QS_S1_X2_04(:,3),'xb',...
    QS_S1_X3_04(:,2),QS_S1_X3_04(:,3),'sb')
hold on
plot(QS_S2_X1_04(:,2),QS_S2_X1_04(:,3),'+r',QS_S2_X2_04(:,2),QS_S2_X2_04(:,3),'dr',...
    QS_S2_X3_04(:,2),QS_S2_X3_04(:,3),'<r')
hold on
plot(QS_S3_X1_04(:,2),QS_S3_X1_04(:,3),'om',QS_S3_X2_04(:,2),QS_S3_X2_04(:,3),'*m',...
    QS_S3_X3_04(:,2),QS_S3_X3_04(:,3),'>m')
hold on
plot(QS_S4_X1_04(:,2),QS_S4_X1_04(:,3),'pc',QS_S4_X2_04(:,2),QS_S4_X2_04(:,3),'vc',...
    QS_S4_X3_04(:,2),QS_S4_X3_04(:,3),'*c')
hold on
plot(QS_S5_X1_04(:,2),QS_S5_X1_04(:,3),'^g',QS_S5_X2_04(:,2),QS_S5_X2_04(:,3),'hg',...
    QS_S5_X3_04(:,2),QS_S5_X3_04(:,3),'>g')
grid on
axis([0 30 0 2e5]);
xlabel('Wave period, T [s]');
ylabel('Overturning moment (quasi-static),OTM [kNm]');  
legend('Seed 1; x_1','Seed 1; x_2','Seed 1; x_3',...
    'Seed 2; x_1','Seed 2; x_2','Seed 2; x_3',...
    'Seed 3; x_1','Seed 3; x_2','Seed 3; x_3',...
    'Seed 4; x_1','Seed 4; x_2','Seed 4; x_3',...
    'Seed 5; x_1','Seed 5; x_2','Seed 5; x_3');

%% PLotting: wave height vs. wave period

figure(3)
plot(QS_S1_X1_04(:,1),QS_S1_X1_04(:,2),'.b',QS_S1_X2_04(:,1),QS_S1_X2_04(:,2),'xb',...
    QS_S1_X3_04(:,1),QS_S1_X3_04(:,2),'sb')
hold on
plot(QS_S2_X1_04(:,1),QS_S2_X1_04(:,2),'+r',QS_S2_X2_04(:,1),QS_S2_X2_04(:,2),'dr',...
    QS_S2_X3_04(:,1),QS_S2_X3_04(:,2),'<r')
hold on
plot(QS_S3_X1_04(:,1),QS_S3_X1_04(:,2),'om',QS_S3_X2_04(:,1),QS_S3_X2_04(:,2),'*m',...
    QS_S3_X3_04(:,1),QS_S3_X3_04(:,2),'>m')
hold on
plot(QS_S4_X1_04(:,1),QS_S4_X1_04(:,2),'pc',QS_S4_X2_04(:,1),QS_S4_X2_04(:,2),'vc',...
    QS_S4_X3_04(:,1),QS_S4_X3_04(:,2),'*c')
hold on
plot(QS_S5_X1_04(:,1),QS_S5_X1_04(:,2),'^g',QS_S5_X2_04(:,1),QS_S5_X2_04(:,2),'hg',...
    QS_S5_X3_04(:,1),QS_S5_X3_04(:,2),'>g')
grid on
xlabel('Wave height, H [m]');
ylabel('Wave period, T [s]');  
legend('Seed 1; x_1','Seed 1; x_2','Seed 1; x_3',...
    'Seed 2; x_1','Seed 2; x_2','Seed 2; x_3',...
    'Seed 3; x_1','Seed 3; x_2','Seed 3; x_3',...
    'Seed 4; x_1','Seed 4; x_2','Seed 4; x_3',...
    'Seed 5; x_1','Seed 5; x_2','Seed 5; x_3');


%% Results from WAVGEN (DYN_No_BL_No_MG)

OTM_WAV = 103786.0;              % [kNm] - overturning moment from WAVGEN
T_WAV = 13.7;
H_WAV = 16.7;

%% Plotting: wave scenario vs.  OTM (maximum and running average)

waves = 1:15;

OTM_max(1) = max(QS_S1_X1_04(:,3));
OTM_max(2) = max(QS_S1_X2_04(:,3));
OTM_max(3) = max(QS_S1_X3_04(:,3));

OTM_max(4) = max(QS_S2_X1_04(:,3));
OTM_max(5) = max(QS_S2_X2_04(:,3));
OTM_max(6) = max(QS_S2_X3_04(:,3));

OTM_max(7) = max(QS_S3_X1_04(:,3));
OTM_max(8) = max(QS_S3_X2_04(:,3));
OTM_max(9) = max(QS_S3_X3_04(:,3));

OTM_max(10) = max(QS_S4_X1_04(:,3));
OTM_max(11) = max(QS_S4_X2_04(:,3));
OTM_max(12) = max(QS_S4_X3_04(:,3));

OTM_max(13) = max(QS_S5_X1_04(:,3));
OTM_max(14) = max(QS_S5_X2_04(:,3));
OTM_max(15) = max(QS_S5_X3_04(:,3));

OTM_sum = cumsum(OTM_max);

for i=1:length(OTM_max)
    
    OTM_aver(i)=OTM_sum(i)/i;
    
end

OTM_WAV_ = OTM_WAV*ones(1,length(waves));

figure(4)
plot(waves(1:3),OTM_max(1:3),'ob','LineWidth',2);
grid on
axis([1 15 0 3e5]);
hold on
plot(waves(4:6),OTM_max(4:6),'or','LineWidth',2);
hold on
plot(waves(7:9),OTM_max(7:9),'om','LineWidth',2);
hold on
plot(waves(10:12),OTM_max(10:12),'oc','LineWidth',2);
hold on
plot(waves(13:15),OTM_max(13:15),'og','LineWidth',2);
grid on
xlabel('Wave scenarios, [-]');
ylabel('Max. overturning moment (quasi-static), OTM [kNm]');
hold on
plot(waves,OTM_aver,'-m','LineWidth',2);
hold on
plot(waves,OTM_WAV_,'--r','LineWidth',2);
legend('Seed 1','Seed 2','Seed 3','Seed 4','Seed 5','Running average','Max. OTM by WAVGEN');
text(2.05,2.75e5,'Breaking filter = 0.4g');

OTM_average = OTM_aver(end)
Difference = (1-OTM_WAV/OTM_average)*100

%% Collecting all data

QS = [QS_S1_X1_04;QS_S1_X2_04;QS_S1_X3_04;...
    QS_S2_X1_04;QS_S2_X2_04;QS_S2_X3_04;...
    QS_S3_X1_04;QS_S3_X2_04;QS_S3_X3_04;...
    QS_S4_X1_04;QS_S4_X2_04;QS_S4_X3_04;...
    QS_S5_X1_04;QS_S5_X2_04;QS_S5_X3_04];

QS_sort = sortrows(QS,-3);

H = 1:20;
T = 1:35;

[x,y] = meshgrid(H,T);

z = ones(length(T),length(H))*OTM_WAV;

%% Scatter diagram

c_ = 1:1:1181;
C = repmat(c_,round((length(QS)/length(c_))),1);
c= sort(C(:),'descend');

figure (5)
scatter3(QS_sort(:,1),QS_sort(:,2),QS_sort(:,3),80,c,'Filled');
axis([0 20 0 35 0 3e5]);
xlabel('Wave height, H [m]');
ylabel('Wave period, T [s]');
zlabel('Overturning moment (quasi-static), OTM [kNm]');
text(H_WAV,T_WAV,OTM_WAV,'Max. OTM by WAVGEN');
text(1,30,2.75e5,'Breaking filter = 0.4g');
a = get(gca,'CLim');

hold on
surf(x,y,z,'EdgeColor','none','FaceColor','r','FaceAlpha',0.1)
plot3(H_WAV+1,T_WAV+1,OTM_WAV,'c*','LineWidth',3)
set(gca,'Clim',a);
hold off

save('QS_04.txt','QS_sort','-ASCII')

%% Running average with differen x-positions

OTM_max2(1) = max(QS_S1_X2_04(:,3));
OTM_max2(2) = max(QS_S1_X3_04(:,3));

OTM_max2(3) = max(QS_S2_X2_04(:,3));
OTM_max2(4) = max(QS_S2_X3_04(:,3));

OTM_max2(5) = max(QS_S3_X2_04(:,3));
OTM_max2(6) = max(QS_S3_X3_04(:,3));

OTM_max2(7) = max(QS_S4_X2_04(:,3));
OTM_max2(8) = max(QS_S4_X3_04(:,3));

OTM_max2(9) = max(QS_S5_X2_04(:,3));
OTM_max2(10) = max(QS_S5_X3_04(:,3));

OTM_sum2 = cumsum(OTM_max2);

for i=1:length(OTM_max2)
    
    OTM_aver2(i)=OTM_sum2(i)/i;
    
end

waves2 = [2 3 5 6 8 9 11 12 14 15];


OTM_max3(1) = max(QS_S1_X3_04(:,3));

OTM_max3(2) = max(QS_S2_X3_04(:,3));

OTM_max3(3) = max(QS_S3_X3_04(:,3));

OTM_max3(4) = max(QS_S4_X3_04(:,3));

OTM_max3(5) = max(QS_S5_X3_04(:,3));


OTM_sum3 = cumsum(OTM_max3);

for i=1:length(OTM_max3)
    
    OTM_aver3(i)=OTM_sum3(i)/i;
    
end

waves3 = [3 6 9 12 15];

figure(6)
plot(waves(1:3),OTM_max(1:3),'ob','LineWidth',2);
axis([1 15 0 3e5]);
grid on
hold on
plot(waves(4:6),OTM_max(4:6),'or','LineWidth',2);
hold on
plot(waves(7:9),OTM_max(7:9),'om','LineWidth',2);
hold on
plot(waves(10:12),OTM_max(10:12),'oc','LineWidth',2);
hold on
plot(waves(13:15),OTM_max(13:15),'og','LineWidth',2);
grid on
xlabel('Wave scenarios, [-]');
ylabel('Max. overturning moment (quasi-static), OTM [kNm]');
hold on
plot(waves,OTM_aver,'-m','LineWidth',2);
hold on
plot(waves2,OTM_aver2,'-y','LineWidth',2);
hold on
plot(waves3,OTM_aver3,'-g','LineWidth',2);
hold on
plot(waves,OTM_WAV_,'--r','LineWidth',2);
legend('Seed 1','Seed 2','Seed 3','Seed 4','Seed 5','Running average (x_1 - x_3)','Running average (x_2 - x_3)','Running average (x_3)','Max. OTM by WAVGEN');
text(2.05,2.75e5,'Breaking filter = 0.4g');

%% Maximum wave height vs. water depth

d = 27.0;           % [m] - water depth

H_all04(1) = max(QS_S1_X1_04(:,1));
H_all04(2) = max(QS_S1_X2_04(:,1));
H_all04(3) = max(QS_S1_X3_04(:,1));
H_all04(4) = max(QS_S2_X1_04(:,1));
H_all04(5) = max(QS_S2_X2_04(:,1));
H_all04(6) = max(QS_S2_X3_04(:,1));
H_all04(7) = max(QS_S3_X1_04(:,1));
H_all04(8) = max(QS_S3_X2_04(:,1));
H_all04(9) = max(QS_S3_X3_04(:,1));
H_all04(10) = max(QS_S4_X1_04(:,1));
H_all04(11) = max(QS_S4_X2_04(:,1));
H_all04(12) = max(QS_S4_X3_04(:,1));
H_all04(13) = max(QS_S5_X1_04(:,1));
H_all04(14) = max(QS_S5_X2_04(:,1));
H_all04(15) = max(QS_S5_X3_04(:,1));

ratio_H_04 = H_all04/d;

load('ratio_H_09.mat')

Ref1 = (ones(1,length(waves)))*0.78;

Ref2 = (ones(1,length(waves)))*0.55;

WAV = (ones(1,length(waves)))*(16.7/d);


waves09 = 1:9;

figure(7)
plot(waves,ratio_H_04,'-r','LineWidth',2)
hold on
plot(waves09,ratio_H_09,'-g','LineWidth',2)
hold on
plot(waves,Ref1,'--m','LineWidth',2)
hold on
plot(waves,Ref2,'--k','LineWidth',2)
hold on
plot(waves,WAV,'--b','LineWidth',2)
grid on
axis([1 15 0 1]);
set(gca,'XTickMode','manual','XTick',waves,'xlim',[1,15]);
xlabel('Wave scenarios, [-]');
ylabel('H_{max}/d, [m]');
legend('BF = 0.4g (5 seeds)','BF = 0.9g (3 seeds)','Reference for solitary waves (H_{max} = 0.78*d)','Alternative reference (H_{max} = 0.55*d)','Embedded stream function','Location','SouthEast');
text(2,0.15,'Water depth = 27.0 m');








