%% Master Thesis - Non-linear Wave Impact on Monopile Structures

%  Philipp Schpfer - KTH (Stockholm) & NTNU (Trondheim)

%  In Corporation With Ramboll Denmark AS, Esbjerg

%  21.06.2016 -  Plotting results of single wave assessment & final evaluation of comparison study
%  OCW3D plus ROSA - breaking filter BF = 0.9g
%  DYNAMIC

clear all
close all
clc

%% Loading data

load('DYN_S1_X1.mat')
load('DYN_S1_X2.mat')
load('DYN_S1_X3.mat')

load('DYN_S2_X1.mat')
load('DYN_S2_X2.mat')
load('DYN_S2_X3.mat')

load('DYN_S3_X1.mat')
load('DYN_S3_X2.mat')
load('DYN_S3_X3.mat')

%% PLotting: wave height vs. OTM

figure(1)
plot(DYN_S1_X1(:,1),DYN_S1_X1(:,3),'.b',DYN_S1_X2(:,1),DYN_S1_X2(:,3),'xb',...
    DYN_S1_X3(:,1),DYN_S1_X3(:,3),'sb')
hold on
plot(DYN_S2_X1(:,1),DYN_S2_X1(:,3),'+r',DYN_S2_X2(:,1),DYN_S2_X2(:,3),'dr',...
    DYN_S2_X3(:,1),DYN_S2_X3(:,3),'<r')
hold on
plot(DYN_S3_X1(:,1),DYN_S3_X1(:,3),'og',DYN_S3_X2(:,1),DYN_S3_X2(:,3),'*g',...
    DYN_S3_X3(:,1),DYN_S3_X3(:,3),'>g')
grid on
xlabel('Wave height, H [m]');
ylabel('Overturning moment (dynamic),OTM [kNm]');  
legend('Seed 1; x_1','Seed 1; x_2','Seed 1; x_3',...
    'Seed 2; x_1','Seed 2; x_2','Seed 2; x_3',...
    'Seed 3; x_1','Seed 3; x_2','Seed 3; x_3');

%% PLotting: wave period vs. OTM

figure(2)
plot(DYN_S1_X1(:,2),DYN_S1_X1(:,3),'.b',DYN_S1_X2(:,2),DYN_S1_X2(:,3),'xb',...
    DYN_S1_X3(:,2),DYN_S1_X3(:,3),'sb')
hold on
plot(DYN_S2_X1(:,2),DYN_S2_X1(:,3),'+r',DYN_S2_X2(:,2),DYN_S2_X2(:,3),'dr',...
    DYN_S2_X3(:,2),DYN_S2_X3(:,3),'<r')
hold on
plot(DYN_S3_X1(:,2),DYN_S3_X1(:,3),'og',DYN_S3_X2(:,2),DYN_S3_X2(:,3),'*g',...
    DYN_S3_X3(:,2),DYN_S3_X3(:,3),'>g')
grid on
xlabel('Wave period, T [s]');
ylabel('Overturning moment (dynamic),OTM [kNm]');  
legend('Seed 1; x_1','Seed 1; x_2','Seed 1; x_3',...
    'Seed 2; x_1','Seed 2; x_2','Seed 2; x_3',...
    'Seed 3; x_1','Seed 3; x_2','Seed 3; x_3');

%% PLotting: wave height vs. wave period

figure(3)
plot(DYN_S1_X1(:,1),DYN_S1_X1(:,2),'.b',DYN_S1_X2(:,1),DYN_S1_X2(:,2),'xb',...
    DYN_S1_X3(:,1),DYN_S1_X3(:,2),'sb')
hold on
plot(DYN_S2_X1(:,1),DYN_S2_X1(:,2),'+r',DYN_S2_X2(:,1),DYN_S2_X2(:,2),'dr',...
    DYN_S2_X3(:,1),DYN_S2_X3(:,2),'<r')
hold on
plot(DYN_S3_X1(:,1),DYN_S3_X1(:,2),'og',DYN_S3_X2(:,1),DYN_S3_X2(:,2),'*g',...
    DYN_S3_X3(:,1),DYN_S3_X3(:,2),'>g')
grid on
xlabel('Wave height, H [m]');
ylabel('Wave period, T [s]');  
legend('Seed 1; x_1','Seed 1; x_2','Seed 1; x_3',...
    'Seed 2; x_1','Seed 2; x_2','Seed 2; x_3',...
    'Seed 3; x_1','Seed 3; x_2','Seed 3; x_3');

%% Results from WAVGEN (DYN_No_BL_No_MG)

OTM_WAV = 124325.0;              % [kNm] - overturning moment from WAVGEN
T_WAV = 13.7;
H_WAV = 16.7;

%% Plotting: wave scenario vs.  OTM (maximum and running average)

waves = 1:9;

OTM_max(1) = max(DYN_S1_X1(:,3));
OTM_max(2) = max(DYN_S1_X2(:,3));
OTM_max(3) = max(DYN_S1_X3(:,3));

OTM_max(4) = max(DYN_S2_X1(:,3));
OTM_max(5) = max(DYN_S2_X2(:,3));
OTM_max(6) = max(DYN_S2_X3(:,3));

OTM_max(7) = max(DYN_S3_X1(:,3));
OTM_max(8) = max(DYN_S3_X2(:,3));
OTM_max(9) = max(DYN_S3_X3(:,3));

OTM_sum = cumsum(OTM_max);

for i=1:length(OTM_max)
    
    OTM_aver(i)=OTM_sum(i)/i;
    
end

OTM_WAV_ = OTM_WAV*ones(1,length(waves));

figure(4)
plot(waves(1:3),OTM_max(1:3),'ob','LineWidth',2);
grid on
hold on
plot(waves(4:6),OTM_max(4:6),'og','LineWidth',2);
hold on
plot(waves(7:9),OTM_max(7:9),'ok','LineWidth',2);
xlabel('Wave scenarios, [-]');
ylabel('Max. overturning moment (dynamic), OTM [kNm]');
hold on
plot(waves,OTM_aver,'-m','LineWidth',2);
hold on
plot(waves,OTM_WAV_,'--r','LineWidth',2);
legend('Seed 1','Seed 2','Seed 3','Running average','Max. OTM by WAVGEN');

%% Collecting all data

DYN = [DYN_S1_X1;DYN_S1_X2;DYN_S1_X3;...
    DYN_S2_X1;DYN_S2_X2;DYN_S2_X3;...
    DYN_S3_X1;DYN_S3_X2;DYN_S3_X3];

DYN_sort = sortrows(DYN,-3);

H = 1:20;
T = 1:30;

[x,y] = meshgrid(H,T);

z = ones(length(T),length(H))*OTM_WAV;

%% Scatter diagram

c_ = 1:1:25;

C = repmat(c_,round((length(DYN)/length(c_))),1);

c= sort(C(:),'descend');
figure (5)
scatter3(DYN_sort(:,1),DYN_sort(:,2),DYN_sort(:,3),80,c,'Filled');
xlabel('Wave height, H [m]');
ylabel('Wave period, T [s]');
zlabel('Overturning moment (dynamic), OTM [kNm]');
text(H_WAV,T_WAV,OTM_WAV,['Max. OTM by WAVGEN']);
a = get(gca,'CLim');

hold on
surf(x,y,z,'EdgeColor','none','FaceColor','r','FaceAlpha',0.1)
plot3(H_WAV+1,T_WAV+1,OTM_WAV,'c*','LineWidth',3)
set(gca,'Clim',a);
hold off

save('DYN.txt','DYN_sort','-ASCII')