%% Master Thesis - Non-linear Wave Impact on Monopile Structures

%  Philipp Schpfer - KTH (Stockholm) & NTNU (Trondheim)

%  In Corporation With Ramboll Denmark AS, Esbjerg

%  21.06.2016 -  Plotting results of single wave assessment & final evaluation of comparison study
%  OCW3D plus ROSA - breaking filter BF = 0.9g
%  QUASI-STATIC 

clear all
close all
clc

%% Loading data

load('QS_S1_X1.mat')
load('QS_S1_X2.mat')
load('QS_S1_X3.mat')

load('QS_S2_X1.mat')
load('QS_S2_X2.mat')
load('QS_S2_X3.mat')

load('QS_S3_X1.mat')
load('QS_S3_X2.mat')
load('QS_S3_X3.mat')

%% PLotting: wave height vs. OTM

figure(1)
plot(QS_S1_X1(:,1),QS_S1_X1(:,3),'.b',QS_S1_X2(:,1),QS_S1_X2(:,3),'xb',...
    QS_S1_X3(:,1),QS_S1_X3(:,3),'sb')
hold on
plot(QS_S2_X1(:,1),QS_S2_X1(:,3),'+r',QS_S2_X2(:,1),QS_S2_X2(:,3),'dr',...
    QS_S2_X3(:,1),QS_S2_X3(:,3),'<r')
hold on
plot(QS_S3_X1(:,1),QS_S3_X1(:,3),'og',QS_S3_X2(:,1),QS_S3_X2(:,3),'*g',...
    QS_S3_X3(:,1),QS_S3_X3(:,3),'>g')
grid on
axis([0 20 0 3e5]);
xlabel('Wave height, H [m]');
ylabel('Overturning moment (quasi-static),OTM [kNm]');  
legend('Seed 1; x_1','Seed 1; x_2','Seed 1; x_3',...
    'Seed 2; x_1','Seed 2; x_2','Seed 2; x_3',...
    'Seed 3; x_1','Seed 3; x_2','Seed 3; x_3','Location','SouthEast');

%% PLotting: wave period vs. OTM

figure(2)
plot(QS_S1_X1(:,2),QS_S1_X1(:,3),'.b',QS_S1_X2(:,2),QS_S1_X2(:,3),'xb',...
    QS_S1_X3(:,2),QS_S1_X3(:,3),'sb')
hold on
plot(QS_S2_X1(:,2),QS_S2_X1(:,3),'+r',QS_S2_X2(:,2),QS_S2_X2(:,3),'dr',...
    QS_S2_X3(:,2),QS_S2_X3(:,3),'<r')
hold on
plot(QS_S3_X1(:,2),QS_S3_X1(:,3),'og',QS_S3_X2(:,2),QS_S3_X2(:,3),'*g',...
    QS_S3_X3(:,2),QS_S3_X3(:,3),'>g')
grid on
axis([0 30 0 3e5]);
xlabel('Wave period, T [s]');
ylabel('Overturning moment (quasi-static),OTM [kNm]');  
legend('Seed 1; x_1','Seed 1; x_2','Seed 1; x_3',...
    'Seed 2; x_1','Seed 2; x_2','Seed 2; x_3',...
    'Seed 3; x_1','Seed 3; x_2','Seed 3; x_3');

%% PLotting: wave height vs. wave period

figure(3)
plot(QS_S1_X1(:,1),QS_S1_X1(:,2),'.b',QS_S1_X2(:,1),QS_S1_X2(:,2),'xb',...
    QS_S1_X3(:,1),QS_S1_X3(:,2),'sb')
hold on
plot(QS_S2_X1(:,1),QS_S2_X1(:,2),'+r',QS_S2_X2(:,1),QS_S2_X2(:,2),'dr',...
    QS_S2_X3(:,1),QS_S2_X3(:,2),'<r')
hold on
plot(QS_S3_X1(:,1),QS_S3_X1(:,2),'og',QS_S3_X2(:,1),QS_S3_X2(:,2),'*g',...
    QS_S3_X3(:,1),QS_S3_X3(:,2),'>g')
grid on
xlabel('Wave height, H [m]');
ylabel('Wave period, T [s]');  
legend('Seed 1; x_1','Seed 1; x_2','Seed 1; x_3',...
    'Seed 2; x_1','Seed 2; x_2','Seed 2; x_3',...
    'Seed 3; x_1','Seed 3; x_2','Seed 3; x_3');

%% Plotting: wave scenario vs.  OTM (maximum and running average)

waves = 1:9;

OTM_max(1) = max(QS_S1_X1(:,3));
OTM_max(2) = max(QS_S1_X2(:,3));
OTM_max(3) = max(QS_S1_X3(:,3));

OTM_max(4) = max(QS_S2_X1(:,3));
OTM_max(5) = max(QS_S2_X2(:,3));
OTM_max(6) = max(QS_S2_X3(:,3));

OTM_max(7) = max(QS_S3_X1(:,3));
OTM_max(8) = max(QS_S3_X2(:,3));
OTM_max(9) = max(QS_S3_X3(:,3));

OTM_sum = cumsum(OTM_max);

for i=1:length(OTM_max)
    
    OTM_aver(i)=OTM_sum(i)/i;
    
end
OTM_WAV = [103786 103786 103786 103786 103786 103786 103786 103786 103786];

figure(4)
plot(waves(1:3),OTM_max(1:3),'ob','LineWidth',2);
grid on
axis([1 9 0 3e5]);
hold on
plot(waves(4:6),OTM_max(4:6),'og','LineWidth',2);
hold on
plot(waves(7:9),OTM_max(7:9),'ok','LineWidth',2);
xlabel('Wave scenarios, [-]');
ylabel('Max. overturning moment (quasi-static), OTM [kNm]');
hold on
plot(waves,OTM_aver,'-m','LineWidth',2);
hold on
plot(waves,OTM_WAV,'--r','LineWidth',2);
legend('Seed 1','Seed 2','Seed 3','Running average','Max. OTM by WAVGEN');
text(2.05,2.75e5,'Breaking filter = 0.9g');

%% Collecting all data

QS = [QS_S1_X1;QS_S1_X2;QS_S1_X3;...
    QS_S2_X1;QS_S2_X2;QS_S2_X3;...
    QS_S3_X1;QS_S3_X2;QS_S3_X3];

QS_sort = sortrows(QS,-3);

%% Results from WAVGEN (QS_No_BL_No_MG)

OTM_WAV = 103786.0;              % [kNm] - overturning moment from WAVGEN
T_WAV = 13.7;
H_WAV = 16.7;

H = 1:20;
T = 1:30;

[x,y] = meshgrid(H,T);

z = ones(length(T),length(H))*OTM_WAV;

c_ = 1:1:25;

C = repmat(c_,round((length(QS)/length(c_))),1);

c= sort(C(:),'descend');
figure (5)
scatter3(QS_sort(:,1),QS_sort(:,2),QS_sort(:,3),80,c,'Filled');
axis([0 20 0 30 0 3e5]);
xlabel('Wave height, H [m]');
ylabel('Wave period, T [s]');
zlabel('Overturning moment (quasi-static), OTM [kNm]');
text(H_WAV,T_WAV,OTM_WAV,'Max. OTM by WAVGEN');
text(1,30,2.75e5,'Breaking filter = 0.9g');
a = get(gca,'CLim');

hold on
surf(x,y,z,'EdgeColor','none','FaceColor','r','FaceAlpha',0.1)
plot3(H_WAV+1,T_WAV+1,OTM_WAV,'c*','LineWidth',3)
set(gca,'Clim',a);
hold off

save('QS_09.txt','QS_sort','-ASCII')

%% Maximumg wave vs. water depth

d = 27.0;           % [m] - water depth

H_all(1) = max(QS_S1_X1(:,1));
H_all(2) = max(QS_S1_X2(:,1));
H_all(3) = max(QS_S1_X3(:,1));
H_all(4) = max(QS_S2_X1(:,1));
H_all(5) = max(QS_S2_X2(:,1));
H_all(6) = max(QS_S2_X3(:,1));
H_all(7) = max(QS_S3_X1(:,1));
H_all(8) = max(QS_S3_X2(:,1));
H_all(9) = max(QS_S3_X3(:,1));


ratio_H_09 = H_all/d;
save('ratio_H_09','ratio_H_09');
