%% Master Thesis - Non-linear Wave Impact on Monopile Structures

%  Philipp Schpfer - KTH (Stockholm) & NTNU (Trondheim)

%  In Corporation With Ramboll Denmark AS, Esbjerg

%  21.06.2016 -  Post-processing of ULS assessment of monopile foundation
%  WAVGEN plus ROSA
 
clear all
close all
clc

%% Reading data
% 1 = no boat landing & no marine growth
% 2 = boat landing & no marine growth 
% 3 = no boat landing & marine growth

data = xlsread('Results.xls');

t = data(:,1);                 % [s] - time

%% Irregular sea state with embedded stream function wave

comb = data(:,2);              % [m] - combined sea state
orig = data(:,3);              % [m] - irregular linear background sea state
repl = data(:,4);              % [m] - replacement wave

%% Quasi-static analysis (QS)

% No boat landing & no marine growth
O_QS_1 = data(:,5);           
F_QS_1 = data(:,6);   

% Boat landing & no marine growth
O_QS_2 = data(:,7);           
F_QS_2 = data(:,8);    

% No boat landing & marine growth
O_QS_3 = data(:,9);           
F_QS_3 = data(:,10);    

%% Dynamic analysis (DYN)

% No boat landing & no marine growth
O_DYN_1 = data(:,11);           
F_DYN_1 = data(:,12);    

% Boat landing & no marine growth
O_DYN_2 = data(:,13);           
F_DYN_2 = data(:,14);    

% No boat landing & marine growth
O_DYN_3 = data(:,15);           
F_DYN_3 = data(:,16); 

%% Irregular linear sea state with embedded stream function

figure(1)
plot(t,comb,'-b','LineWidth',3);
hold on
plot(t,orig,'--r','LineWidth',2);
hold on
plot(t,repl,'--g','LineWidth',2);
grid on
xlabel('Time, t [s]');
ylabel('Surface elevation, \eta [m]');
legend('Combined sea state','Irregular linear sea state','Replacement wave');

%% Quasi-static: wave forces with or without boat landing/marine growth

figure(2)
plot(t,F_QS_1,'-b',t,F_QS_2,'-r',t,F_QS_3,'--g','LineWidth',2);
grid on
xlabel('Time, t [s]');
ylabel('Wave loads (quasi-static), FS [kN]');
legend('No BL & No MG','BL & No MG','No BL & MG');

%% Dynamic: wave forces with or without boat landing/marine growth

figure(3)
plot(t,F_DYN_1,'-b',t,F_DYN_2,'-r',t,F_DYN_3,'-g','LineWidth',2);
grid on
xlabel('Time, t [s]');
ylabel('Wave loads (dynamic), FS [kN]');
legend('No BL & No MG','BL & No MG','No BL & MG');

%% No boat landing & no marine growth: wave loads (quasi-static vs. dynamic)

figure(4)
[AX,H1,H2] = plotyy(t,F_QS_1,t,comb);
grid on
hold on; 
plot(t,F_DYN_1,'-g','LineWidth',2);
set(H1,'Color','r');
set(H2,'Color','b');
set(H1,'LineWidth',2);
set(H2,'LineWidth',2);
legend('Quasi-static','Dynamic','Wave profile','Location','SouthEast');

% set(AX(1),'XLim', [0 3600]);
% set(AX(2),'XLim', [0 3600]);
set(AX(1),'YLim', [-6000 6000]);
% set(AX(1),'YTick', -4e5:1e5:4e5);
set(AX(2),'YLim', [-15 15]);
% set(AX(2),'YTick', -15:3:15);
set(AX(1),'YColor','k');
set(AX(2),'YColor','k');

set(get(AX(1),'Ylabel'),'string','Wave loads, FS [kN]','Color','r');
set(get(AX(2),'Ylabel'),'string','Surface elevation, \eta [m]','Color','b');
xlabel('Time, t [s]');

%% No boat landing & no marine growth: OTM (quasi-static vs. dynamic)

figure(5)
[AX,H1,H2] = plotyy(t,O_QS_1,t,comb);
grid on
hold on; 
plot(t,O_DYN_1,'-g','LineWidth',2);
set(H1,'Color','r');
set(H2,'Color','b');
set(H1,'LineWidth',2);
set(H2,'LineWidth',2);
legend('Quasi-static','Dynamic','Wave profile','Location','SouthEast');

% set(AX(1),'XLim', [0 3600]);
% set(AX(2),'XLim', [0 3600]);
set(AX(1),'YLim', [-1.5e5 1.5e5]);
% set(AX(1),'YTick', -4e5:1e5:4e5);
set(AX(2),'YLim', [-15 15]);
% set(AX(2),'YTick', -15:3:15);
set(AX(1),'YColor','k');
set(AX(2),'YColor','k');

set(get(AX(1),'Ylabel'),'string','Overturning moment, OTM [kNm]','Color','r');
set(get(AX(2),'Ylabel'),'string','Surface elevation, \eta [m]','Color','b');
xlabel('Time, t [s]');

% End of code