%% Master Thesis - Non-linear Wave Impact on Monopile Structures

%  Philipp Schpfer - KTH (Stockholm) & NTNU (Trondheim)

%  In Corporation With Ramboll Denmark AS, Esbjerg

%  15.06.2016 -  WAVGEN wave database
%  NewWave, Sinusoidal, Deep sinusoidal,Stokes' 5th order, Stream function wave 
 
clear all
close all
clc

%% Reading data

data = xlsread('WAVGEN.xls');

x = data(:,1);                % [m] - x-position

%% Deep water

NW_d = data(:,2);             % [m] - NewWave
SIN_d = data(:,3);            % [m] - Sinusoidal
DSIN_d = data(:,4);           % [m] - Deep Sinusoidal
ST_d = data(:,5);             % [m] - Stokes' 5th order
SF5_d = data(:,6);            % [m] - Stream function wave 5th order
SF20_d = data(:,7);           % [m] - Stream function wave 20th order
SF42_d = data(:,8);           % [m] - Stream function wave 42nd order

figure(1)
plot(x,NW_d,'-b',...
    x,SIN_d,'--r',...
    x,DSIN_d,'-.g',...
    x,ST_d,':c',...
    x,SF5_d,'-y',...
    x,SF20_d,'-m',...
    x,SF42_d,':k','LineWidth',2);
grid on
axis([-100 100 -5 5]);
graph2d.constantline(0);
xlabel('x-position, x [m]');
ylabel('Surface elevation (deep water), \eta [m]');
legend('NewWave','Sinusoidal','Deep sinusoidal','Stokes` 5^t^h order',...
    'Stream function wave 5^t^h order','Stream function wave 20^t^h order',...
    'Stream function wave 42^n^d order');
text(92,0.15,'SWL')

%% SHallow water

NW_s = data(:,9);              % [m] - NewWave
SIN_s = data(:,10);            % [m] - Sinusoidal
DSIN_s = data(:,11);           % [m] - Deep Sinusoidal
ST_s = data(:,12);             % [m] - Stokes' 5th order
SF5_s = data(:,13);            % [m] - Stream function wave 5th order
SF20_s = data(:,14);           % [m] - Stream function wave 20th order
SF42_s = data(:,15);           % [m] - Stream function wave 42nd order

figure(2)
plot(x,NW_s,'-b',...
    x,SIN_s,'-r',...
    x,DSIN_s,'-g',...
    x,ST_s,'-c',...
    x,SF5_s,'-y',...
    x,SF20_s,'--m',...
    x,SF42_s,':k','LineWidth',2);
grid on
axis([-100 100 -5 5]);
graph2d.constantline(0);
xlabel('x-position, x [m]');
ylabel('Surface elevation (shallow water), \eta [m]');
legend('NewWave','Sinusoidal','Deep sinusoidal','Stokes` 5^t^h order',...
    'Stream function wave 5^t^h order','Stream function wave 20^t^h order',...
    'Stream function wave 42^n^d order');
text(92,0.15,'SWL')

% End of Code